@@ -8,6 +8,7 @@ from .sendfiles import vipersubscribeconsumer
 from .sendfiles import viperunsubscribeconsumer
 
 from .sendfiles import viperproducetotopic
+from .sendfiles import viperproducetotopicbulk
 from .sendfiles import viperconsumefromtopic
 from .sendfiles import viperhpdepredict
 
@@ -17,6 +18,8 @@ from .sendfiles import viperhpdetraining
 
 from .sendfiles import viperproducetotopicstream
 
+from .sendfiles import viperpreprocessproducetotopicstream
+
 from .sendfiles import vipercreatetrainingdata
     
 
